
0.3.1
-----

* Refactor ``rattail.hw.cognitive`` -> ``rattail_cognitive``.


0.3a3
-----

- [general] Fixed namespace package declaration.

- [general] Added initial Fabric script.


0.3a2
-----

- Tweaked default label format.

0.3a1
-----

-  Initial port to Rattail v0.3.
